==> OpenCL-0.8.5.tgz: OpenCL-0.8.5/doc/examples/stack.cpp <==
/*
An OpenCL example application showing how to use the pop and prepend functions
of Pipe. Based on the md5 example. It's output should always be identical to
such.

Written by Jack Lloyd (lloyd@acm.jhu.edu), Feb 3, 2002

This file is in the public domain
*/

#include <iostream>
#include <fstream>
#include <opencl/filters.h>
#include <opencl/hex.h>
#include <opencl/md5.h>
#include <opencl/sha1.h>
#include <opencl/rmd160.h>

int main(int argc, char* argv[])
   {
   if(argc < 2)
      {
      std::cout << "Usage: stack <filenames>" << std::endl;
      return 1;
      }

   OpenCL::LibraryInitializer init;

   OpenCL::Pipe pipe;

   // this is a pretty vacuous example, but it's useful as a test
   pipe.prepend(new OpenCL::Hash_Filter(new OpenCL::MD5));
   pipe.prepend(new OpenCL::Hash_Filter(new OpenCL::RIPEMD_160));
   pipe.prepend(new OpenCL::Chain(
                   new OpenCL::Hash_Filter(new OpenCL::RIPEMD_160),
                   new OpenCL::Hash_Filter(new OpenCL::RIPEMD_160)));
   pipe.pop(); // will pop everything inside the Chain as well as Chain itself
   pipe.pop(); // will get rid of the RIPEMD-160 Hash_Filter
   pipe.prepend(new OpenCL::Hash_Filter(new OpenCL::SHA1));
   pipe.append(new OpenCL::Hex_Encoder);
   pipe.prepend(new OpenCL::Hash_Filter(new OpenCL::SHA1));
   pipe.pop(); // Get rid of the Hash_Filter(SHA1)
   pipe.pop(); // Get rid of the other Hash_Filter(SHA1)
       // The Hex_Encoder is safe because it is at the end of the Pipe,
       // and pop() pulls off the Filter that is at the start.
   pipe.prepend(new OpenCL::Hash_Filter(new OpenCL::RIPEMD_160));
   pipe.pop(); // Get rid of that last prepended Hash_Filter(RIPEMD-160)

   int skipped = 0;
   for(int j = 1; argv[j] != 0; j++)
      {
      std::ifstream file(argv[j]);
      if(!file)
         {
         std::cout << "ERROR: could not open " << argv[j] << std::endl;
         skipped++;
         continue;
         }
      pipe.start_msg();
      file >> pipe;
      pipe.end_msg();
      file.close();
      pipe.set_default_msg(j-1-skipped);
      std::cout << pipe << "  " << argv[j] << std::endl;
      }
   return 0;
   }

==> OpenCL-0.8.6.tgz: OpenCL-0.8.6/doc/examples/stack.cpp <==
/*
An OpenCL example application showing how to use the pop and prepend functions
of Pipe. Based on the md5 example. It's output should always be identical to
such.

Written by Jack Lloyd (lloyd@acm.jhu.edu), Feb 3, 2002

This file is in the public domain
*/

#include <iostream>
#include <fstream>
#include <opencl/filters.h>
#include <opencl/hex.h>

int main(int argc, char* argv[])
   {
   if(argc < 2)
      {
      std::cout << "Usage: stack <filenames>" << std::endl;
      return 1;
      }

   OpenCL::LibraryInitializer init;

   OpenCL::Pipe pipe;

   // this is a pretty vacuous example, but it's useful as a test
   pipe.prepend(new OpenCL::Hash_Filter("MD5"));
   pipe.prepend(new OpenCL::Hash_Filter("RIPEMD-160"));
   pipe.prepend(new OpenCL::Chain(
                   new OpenCL::Hash_Filter("RIPEMD-160"),
                   new OpenCL::Hash_Filter("RIPEMD-160")));
   pipe.pop(); // will pop everything inside the Chain as well as Chain itself
   pipe.pop(); // will get rid of the RIPEMD-160 Hash_Filter
   pipe.prepend(new OpenCL::Hash_Filter("SHA-1"));
   pipe.append(new OpenCL::Hex_Encoder);
   pipe.prepend(new OpenCL::Hash_Filter("SHA-1"));
   pipe.pop(); // Get rid of the Hash_Filter(SHA-1)
   pipe.pop(); // Get rid of the other Hash_Filter(SHA-1)
       // The Hex_Encoder is safe because it is at the end of the Pipe,
       // and pop() pulls off the Filter that is at the start.
   pipe.prepend(new OpenCL::Hash_Filter("RIPEMD-160"));
   pipe.pop(); // Get rid of that last prepended Hash_Filter(RIPEMD-160)

   int skipped = 0;
   for(int j = 1; argv[j] != 0; j++)
      {
      std::ifstream file(argv[j]);
      if(!file)
         {
         std::cout << "ERROR: could not open " << argv[j] << std::endl;
         skipped++;
         continue;
         }
      pipe.start_msg();
      file >> pipe;
      pipe.end_msg();
      file.close();
      pipe.set_default_msg(j-1-skipped);
      std::cout << pipe << "  " << argv[j] << std::endl;
      }
   return 0;
   }
